namespace Grendel.Base {  
   using System;
   using System.Reflection;
   
   public class Inspector : BaseCanvasObject{
      ICanvasObject target;
      Type targetType;
      
      private static Type[] supportedTypes = new Type[]{
            typeof(bool),
            typeof(string),
            typeof(int),
            typeof(double),
            typeof(Color)
      };
      
      public Inspector(Canvas canvas, ICanvasObject target) 
      : base(canvas){
        this.target = target;
        targetType = this.target.GetType();
      }
        
      public void MethodLauncher(){
         IDialogBuilder db = Canvas.DialogBuilder;
         foreach(MethodInfo mi in targetType.GetMethods(BindingFlags.Instance | BindingFlags.Public))
            if(mi.GetParameters().Length == 0 && !mi.IsSpecialName  
                && mi.ReturnType == typeof(void)) {
                     db.AddButton(mi.Name);
             }
         string methodName = db.ExecuteDialog(200, StandardButtons.Cancel);
         if(methodName == "Cancel" || methodName == "")
            return;
         targetType.GetMethod(methodName).Invoke(target, null);
         Canvas.Invalidate();
      }
   
      public void PropertyDialog() {
         IDialogBuilder db = Canvas.DialogBuilder;
         foreach(PropertyInfo p in targetType.GetProperties()) {
            if(Array.IndexOf(supportedTypes, p.PropertyType) >= 0)
               db.AddInput(p.Name, p.GetValue(target,null));
         }
         string button = db.ExecuteDialog(300, StandardButtons.OK | StandardButtons.Cancel);
         if(button == "Cancel" || button == "")
            return;
         foreach(string key in db.Keys) {
            targetType.GetProperty(key).SetValue(target, db.GetValue(key), null);
         }
         Canvas.Invalidate();
      }  
   }
}