// Button.cs created with MonoDevelop
// User: fiser at 11:21 28.7.2008
//
// To change standard headers go to Edit->Preferences->Coding->Standard Headers
//
namespace Grendel.Ui {
   using Grendel.Base;
   
   public abstract class Button : BaseInteractiveShape {
      private string text;
      private double width;
      private double height;
      
      public Button(Canvas canvas, string text, double width) : base(canvas) {
         this.text = text;
         this.width = width;
         this.height = 24.0;
      }
      
      public override Position LeftTopCorner {
         get { return Position.Origin; }
      }
      
      public override Position RightBottomCorner {
         get { return new Position(width, height); }
      }

      public string Label {
         get {
            return text;
         }
         set {
            text = value;
         }
      }
      
      public override void Painting () {
         Canvas.DrawRectangle(this, LeftTopCorner, RightBottomCorner, Color.Black);
         double shift = (width - (Font.Monospace.Size - 2) * text.Length) / 2.0;
         Canvas.DrawText(this, new Position(shift, 5), Label);
      }
      
      
      public override void Interaction (MouseButtons button, Position location) {
         if(button.IsPressedLeft)
            Action();
      }
      
      public abstract void Action();
   }
   
   public class CloneButton : Button, IEventListener {
      ICanvasCloneable pattern;
      MouseEventTarget oldTarget;
      
      public CloneButton(Canvas canvas, string text, double width, ICanvasCloneable pattern) 
       : base(canvas, text, width){
         this.pattern = pattern;
      }
      
      public override void Action () {
         oldTarget = Canvas.MouseEventTarget;
         Canvas.MouseEventTarget = MouseEventTarget.EventListeners;
         Canvas.AddEventListener(this);
      }
      
      public void MouseEventHandler (MouseButtons buttons, Position absolutePosition)
      {
         Canvas.RemoveEventListener(this);
         Canvas.MouseEventTarget = oldTarget;
         IShape shape = pattern.Clone() as IShape;
         if(shape != null) {
          shape.Location = absolutePosition;  
         }
      }


   }
} 
