using Grendel.Base;
using Grendel.Extra;
using Grendel.Example;
using Grendel.Ui;
using System;

class Test {
   public static void Main() {
      Canvas canvas = (new CanvasFactory(850,850)).BestCanvas;
        
       Console.WriteLine(canvas.TextWidth("LeGoLas", Font.Monospace));
      
      InteractiveGreekCross c = new InteractiveGreekCross(canvas, 20.0);
      c.Location = new Position(100, 100);
      c.BaseColor = Color.Red;
      
      Text t = new TextWithFont(canvas, "Frodo", new Font("Arial", 25, FontStyle.BoldItalic));
      t.Location = new Position(200,200);
      t.BaseColor = Color.Green + 0.5 * Color.Black;
      
      new FrameCounter(canvas);
      
      Star s = new Star(canvas);
      s.Location = new Position(300, 300);
      s.BaseColor = (Color.Blue + 0.5*Color.Black).WithTransparence(80);
	  s.LocalTransformation.Rotate(10.0);
      
      (new CloneButton(canvas, "New star", 100, s)).Location = new Position(100,0);
      
	  ResourceBitmap bmp = new ResourceBitmap(canvas, "grendel.jpeg");
      bmp.Location = new Position(150,250);
	  bmp.LocalTransformation.Rotate(30.0);
		
	  GreekCross c1 = new GreekCross(canvas, 50);
	  GreekCross c2 = new GreekCross(canvas, 50);
	
	   c1.LocalTransformation.Rotate(45);
	   c2.LocalTransformation.Rotate(45);
	   c1.LocalTransformation.Translate(new Vector(0, 15));
		
	  CompositeShape cs = new CompositeShape(canvas);
		
	  cs.AddSubshape(c1, new Position(25,25));
	  cs.AddSubshape(c2, new Position(25,75));
		
	  cs.Location = new Position(200,100);
	  cs.LocalTransformation.Rotate(12);
	  cs.LocalTransformation.Scale(1.0, 0.1);
		
	  InteractiveGreekCross ic1= new InteractiveGreekCross(canvas, 20);
	  InteractiveGreekCross ic2= new InteractiveGreekCross(canvas, 30);
	  InteractiveGreekCross ic3= new InteractiveGreekCross(canvas, 45);
	  ic1.LocalTransformation.Rotate(64);
	  ic2.LocalTransformation.Rotate(70);	
	  ic3.LocalTransformation.Rotate(45);
		
	  CompositeInteractiveShape ics = new CompositeInteractiveShape(canvas);
	  ics.Location = new Position(400,400);
		
	  ics.AddSubshape(ic1, new Position(10, 10), true);	                 
	  ics.AddSubshape(ic2, new Position(50, 50), true);
	  ics.AddSubshape(ic3, new Position(50, 27), true);	
		
	
	  BezierCurve curve = new BezierCurve(canvas, Position.Origin, new Vector(1.0, 1.0), 
		                                            new Position(2.0, 1.0), new Vector(0.0, -1.0));
	  curve.Location = new Position(500, 200);
	  curve.LocalTransformation.Scale(20.0, 20.0);
        
      UnitCircle circle = new UnitCircle(canvas);
	  circle.Location = new Position(580, 200);
      circle.LineWidth = 0.05;
	  circle.LocalTransformation.Scale(25.0, 25.0);  
        
      ActionLauncher launcher = new ActionLauncher(canvas);
      for(int i=50; i <=200; i += 10) {
            launcher.AddAction(i, delegate(int frame) {
               Text txt = new Text(canvas, string.Format("{0}", frame));
                txt.Location = new Position(frame, frame);
                txt.Layer = -10;
            });
      }
      canvas.Display();
   }
}